==> apache-doris-2.0.15.1-src.tar.gz: apache-doris-2.0.15.1-src/fe/fe-core/src/main/java/org/apache/doris/task/ReleaseSnapshotTask.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.doris.task;

import org.apache.doris.thrift.TReleaseSnapshotRequest;
import org.apache.doris.thrift.TResourceInfo;
import org.apache.doris.thrift.TTaskType;

public class ReleaseSnapshotTask extends AgentTask {

    private String snapshotPath;

    public ReleaseSnapshotTask(TResourceInfo resourceInfo, long backendId, long dbId, long tabletId,
                               String snapshotPath) {
        super(resourceInfo, backendId, TTaskType.RELEASE_SNAPSHOT, dbId, -1, -1, -1, tabletId);
        this.snapshotPath = snapshotPath;
    }

    public TReleaseSnapshotRequest toThrift() {
        TReleaseSnapshotRequest request = new TReleaseSnapshotRequest(snapshotPath);
        return request;
    }
}

==> apache-doris-4.0.2-rc02-src.tar.gz: apache-doris-4.0.2-rc02-src/fe/fe-core/src/main/java/org/apache/doris/task/ReleaseSnapshotTask.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.doris.task;

import org.apache.doris.thrift.TReleaseSnapshotRequest;
import org.apache.doris.thrift.TResourceInfo;
import org.apache.doris.thrift.TTaskType;

public class ReleaseSnapshotTask extends AgentTask {

    private String snapshotPath;
    private boolean isJobCompleted; // now only for cloud

    public ReleaseSnapshotTask(TResourceInfo resourceInfo, long backendId, long dbId, long tabletId,
                               String snapshotPath, boolean isJobCompleted) {
        super(resourceInfo, backendId, TTaskType.RELEASE_SNAPSHOT, dbId, -1, -1, -1, tabletId);
        this.snapshotPath = snapshotPath;
        this.isJobCompleted = isJobCompleted;

    }

    public TReleaseSnapshotRequest toThrift() {
        TReleaseSnapshotRequest request = new TReleaseSnapshotRequest(snapshotPath);
        request.setTabletId(tabletId);
        request.setIsJobCompleted(isJobCompleted);
        return request;

    }
}
